@@ -81,6 +81,14 @@ typedef enum {
   STATE_EXTRACTING
 } TrackState;
 
+typedef enum {
+  DEBUG_ALL = 1 << 0,
+  DEBUG_CD = 1 << 1,
+  DEBUG_METADATA = 1 << 2,
+  DEBUG_EXTRACTING = 1 << 3,
+  DEBUG_PLAYING = 1 << 4,
+} SjDebugDomain;
+
 /**
  * The GtkTreeModel which all of the tracks are stored in
  */
@@ -126,6 +134,11 @@ extern gboolean autostart;
  */
 extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 
+/**
+ * Debug
+ */
+void sj_debug (SjDebugDomain domain, const gchar* format, ...);
+
 /**
  * GConf key names
  */
@@ -139,7 +152,8 @@ extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
 #define GCONF_AUDIO_PROFILE GCONF_ROOT "/audio_profile"
 #define GCONF_PARANOIA GCONF_ROOT "/paranoia"
 #define GCONF_STRIP GCONF_ROOT "/strip-special"
-#define GCONF_MUSICBRAINZ_SERVER GCONF_ROOT "/musicbrainz_server"
+#define GCONF_WINDOW GCONF_ROOT "/window"
+#define GCONF_AUDIO_VOLUME GCONF_ROOT "/volume"
 
 #define GCONF_PROXY_ROOT "/system/http_proxy"
 #define GCONF_HTTP_PROXY_ENABLE GCONF_PROXY_ROOT "/use_http_proxy"
